@@ -15,13 +15,13 @@ class Spkio:
         out = {
             'source': p['source'],
             'date': {
-                   'year': p['date'].year,
-                   'month': p['date'].month,
-                   'day': p['date'].day
-            }
+                   'year': p['date']['year'] if 'year' in p['date'] else None,
+                   'month': p['date']['month'] if 'month' in p['date'] else None,
+                   'day': p['date']['day'] if 'day' in p['date'] else None,
+            } if 'date' in p else None
         }
         res = self.req.post(f'{self.URL_SPKIO_SERVICE}/source', json = out)
-        return self.catchCreatedResponse(res)
+        return self._catchCreatedResponse(res)
 
     def createLink(self, idFrom, idKey, el, idSource, idKeyBind=None):
         return self.bindLink(idFrom, idKeyBind, self.createNode(el, idKey, idSource), idSource)
@@ -33,11 +33,11 @@ class Spkio:
         }
         if idKey != None: out['idKey'] = idKey
         res = self.req.post(f'{self.URL_SPKIO_SERVICE}/link/{idSource}', json = out)
-        return self.catchCreatedResponse(res)
+        return self._catchCreatedResponse(res)
 
     def createGlossary(self, el, idSource, relevance=0, searchable=False):
         res = self.req.post(f'{self.URL_SPKIO_SERVICE}/glossary/{idSource}', json = {'key': el['tx_text'], 'relevance': relevance, 'searchable': searchable})
-        return self.catchCreatedResponse(res)
+        return self._catchCreatedResponse(res)
 
     def createNode(self, el, idKey=None, idSource=None):
         out = {
@@ -61,7 +61,7 @@ class Spkio:
             }
         }
         res = self.req.post(f'{self.URL_SPKIO_SERVICE}/node/{idSource}', json = out)
-        return self.catchCreatedResponse(res)
+        return self._catchCreatedResponse(res)
     
     def getAcquisitionBySha512(self, sha512):
         res = self.req.get(f'{self.URL_SPKIO_SERVICE}/acquisition/sha512/{sha512}')
@@ -69,11 +69,19 @@ class Spkio:
         if res.status_code == 404: return None
         raise Exception(res)
     
-    def postAcquisitionBySha512MarkDone(self, sha512):
-        res = self.req.post(f'{self.URL_SPKIO_SERVICE}/acquisition/sha512/{sha512}/done')
+    def postAcquisitionBySha512MarkDone(self, sha512, tag):
+        res = self.req.post(f'{self.URL_SPKIO_SERVICE}/acquisition/sha512/{sha512}/{tag}')
         if res.status_code == 200: return json.loads(res.content)
         raise Exception(res)
 
-    def catchCreatedResponse(self, res):
-        if res.status_code != 201: raise Exception(res)
+    def _catchCreatedResponse(self, res):
+        if res.status_code != 201: 
+            req = res.request
+            print('ERROR --------------')
+            print(f'{req.method}: {req.url}')
+            print(f'{req.status_code}: {req.reason}')
+            print(f'headers: {req.headers}')
+            print(f'body: {req.body}')
+            print('-------------- ERROR')
+            raise Exception(res)
         return res.headers['Location'].split('/')[-1]
